"use strict";

exports.__esModule = true;
exports.collectComponent = collectComponent;
exports.createComponent = createComponent;
var _component = require("../component");
/** Retains a pool of Components for re-use, keyed on component name.
 *	Note: since component names are not unique or even necessarily available, these are primarily a form of sharding.
 *	@private
 */
var components = {};

/** Reclaim a component for later re-use by the recycler. */
function collectComponent(component) {
  var name = component.constructor.name;
  (components[name] || (components[name] = [])).push(component);
}

/** Create a component. Normalizes differences between PFC's and classful Components. */
function createComponent(Ctor, props, context) {
  var list = components[Ctor.name],
    inst;
  if (Ctor.prototype && Ctor.prototype.render) {
    inst = new Ctor(props, context);
    _component.Component.call(inst, props, context);
  } else {
    inst = new _component.Component(props, context);
    inst.constructor = Ctor;
    inst.render = doRender;
  }
  if (list) {
    for (var i = list.length; i--;) {
      if (list[i].constructor === Ctor) {
        inst.nextBase = list[i].nextBase;
        list.splice(i, 1);
        break;
      }
    }
  }
  return inst;
}

/** The `.render()` method for a PFC backing instance. */
function doRender(props, state, context) {
  return this.constructor(props, context);
}